/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.TracerNotification.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef TRACERNOTIFICATIONINTERFACE_H
#define TRACERNOTIFICATIONINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.TracerNotification
 */
class OrgFreedesktopAkonadiTracerNotificationInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.TracerNotification"; }

public:
    OrgFreedesktopAkonadiTracerNotificationInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiTracerNotificationInterface();

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void connectionDataInput(const QString &identifier, const QString &msg);
    void connectionDataOutput(const QString &identifier, const QString &msg);
    void connectionEnded(const QString &identifier, const QString &msg);
    void connectionStarted(const QString &identifier, const QString &msg);
    void errorEmitted(const QString &componentName, const QString &msg);
    void signalEmitted(const QString &signalName, const QString &msg);
    void warningEmitted(const QString &componentName, const QString &msg);
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      using TracerNotification = ::OrgFreedesktopAkonadiTracerNotificationInterface;
    }
  }
}

#endif
